[![Build Status](https://travis-ci.org/olalonde/node-yelp.svg?branch=master)](https://travis-ci.org/olalonde/node-yelp) [![NPM version](https://badge.fury.io/js/yelp.png)](http://badge.fury.io/js/yelp)

Node.js module for interfacing with [Yelp](http://www.yelp.com)'s API
v3.0. Supports both promises and callbacks.

# Install

```
npm install --save node-yelp-v3
```

# Usage

```javascript
// Request API access: http://www.yelp.com/developers/getting_started/api_access
var Yelp = require('yelp');

var yelp = new Yelp({
  consumer_key: 'consumer-key',
  consumer_secret: 'consumer-secret'
});

// See https://www.yelp.com/developers/documentation/v3/business_search
yelp.search({ term: 'food', location: 'Montreal' })
.then(function (data) {
  console.log(data);
})
.catch(function (err) {
  console.error(err);
});

// See https://www.yelp.com/developers/documentation/v3/business
yelp.business('yelp-san-francisco')
  .then(console.log)
  .catch(console.error);

// See https://www.yelp.com/developers/documentation/v3/business_search_phone
yelp.phoneSearch({ phone: '+15555555555' })
  .then(console.log)
  .catch(console.error);

// A callback based API is also available:
yelp.business('yelp-san-francisco', function(err, data) {
  if (err) return console.log(error);
  console.log(data);
});
```

See [./test](./test) for more usage examples.

# References

- [Search API](https://www.yelp.com/developers/documentation/v3/business_search)
- [Business API](https://www.yelp.com/developers/documentation/v3/business)
- [Phone API](https://www.yelp.com/developers/documentation/v3/business_search_phone)

# Test

```bash
CONSUMER_KEY="" CONSUMER_SECRET="" TOKEN="" TOKEN_SECRET="" npm test
```

# License

Copyright (c) 2016 Kristen Kehlenbeck <klkehlenbeck@gmail.com>

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
